Contains logic for extracting events and other data from host chain blocks.
Usage
Create a Extractor from a set of SignetSystemConstants, then invoke
Extractor::extract_signet to extract all relevant Signet events from a
chain.
These events will be returned as a series of Extracts objects, each of
which containing the relevant ExtractedEvents and a AggregateFills
for a specific host block.
Structs
- Extracted
Event - A single event extracted from the host chain.
- Extractor
- Extracts Zenith events from a chain.
- Extracts
- The output of the block extraction process. This struct contains borrows
from a block object, the extracted events, and a
AggregateFillspopulated with the fills present in the host block.
Enums
- Events
- Events that we expect to find on the host chain.
Traits
- Extract
Step - The extract step trait defines an object that can extract data from logs in transaction receipts.
- Extractable
- A trait for types from which data can be extracted. This currently exists to provide a common interface for extracting data from host chain blocks and receipts which may be in alloy or reth types.
- HasTxns
- A trait for types that contain transactions. This currently exists to provide a common interface for extracting data from host chain blocks and receipts which may be in alloy or reth types.